@@ -2,7 +2,7 @@ newspaceskel<-function(n,startspace,currspace,softlimit,hardlimit,posterior,blac
                        MCMCtrace=NULL,mergetype="skeleton") {
   switch(mergetype,
          "dag" = { 
-           mdag<-dag.threshold(n,MCMCtrace,pbarrier=posterior,pdag=FALSE)
+           mdag<-dag.threshold(MCMCtrace,pbarrier=posterior,pdag=FALSE)
            newadj<-1*(!blacklist&(startspace|mdag))
            toomanyneib<-which(apply(newadj,2,sum)>hardlimit)
            if(length(toomanyneib)>0){newadj[,toomanyneib]<-(1*(!blacklist&mdag))[,toomanyneib]}
@@ -14,7 +14,7 @@ newspaceskel<-function(n,startspace,currspace,softlimit,hardlimit,posterior,blac
            newadj<-1*(!blacklist&(startspace|mcp))
            toomanyneib<-which(apply(newadj,2,sum)>softlimit)
            if(length(toomanyneib)>0) {
-             mdag<-dag.threshold(n,MCMCtrace,pbarrier=posterior,pdag=FALSE)
+             mdag<-dag.threshold(MCMCtrace,pbarrier=posterior,pdag=FALSE)
              newadj[,toomanyneib]<-(1*(!blacklist&(startspace|mdag)))[,toomanyneib]
            }
            tootoomanyneib<-which(apply(newadj,2,sum)>hardlimit)
@@ -23,15 +23,15 @@ newspaceskel<-function(n,startspace,currspace,softlimit,hardlimit,posterior,blac
            if(length(tootoomanyneib)>0) {newadj[,tootoomanyneib]<-currspace[,tootoomanyneib]}
          },
          "skeleton" = { 
-           mskel<-1*(dag.threshold(n,MCMCtrace,pbarrier=posterior,pdag=FALSE)|t(dag.threshold(n,MCMCtrace,pbarrier=posterior,pdag=FALSE)))
+           mskel<-1*(dag.threshold(MCMCtrace,pbarrier=posterior,pdag=FALSE)|t(dag.threshold(MCMCtrace,pbarrier=posterior,pdag=FALSE)))
            newadj<-1*(!blacklist&(startspace|mskel))
            toomanyneib<-which(apply(newadj,2,sum)>4)
            if(length(toomanyneib)>0) {
-             newadj[,toomanyneib]<-(1*(!blacklist&(startspace|dag.threshold(n,MCMCtrace,pbarrier=posterior,pdag=TRUE))))[,toomanyneib]
+             newadj[,toomanyneib]<-(1*(!blacklist&(startspace|dag.threshold(MCMCtrace,pbarrier=posterior,pdag=TRUE))))[,toomanyneib]
            }
            toomanyneib<-which(apply(newadj,2,sum)>softlimit)
            if(length(toomanyneib)>0) {
-             mdag<-dag.threshold(n,MCMCtrace,pbarrier=posterior,pdag=FALSE)
+             mdag<-dag.threshold(MCMCtrace,pbarrier=posterior,pdag=FALSE)
              newadj[,toomanyneib]<-(1*(!blacklist&(startspace|mdag)))[,toomanyneib]
            }
            tootoomanyneib<-which(apply(newadj,2,sum)>hardlimit)
@@ -44,7 +44,7 @@ newspaceskel<-function(n,startspace,currspace,softlimit,hardlimit,posterior,blac
 }
 
 newspacemap<-function(n,startspace,currspace,softlimit,hardlimit,blacklist, 
-                      maxN,MCMCtrace=NULL,mergetype="skeleton") {
+                      maxN,MCMCtrace=NULL,mergetype="skeleton",accum) {
   switch(mergetype,
          "dag" = { 
            maxdag<-MCMCtrace[[maxN]]
@@ -53,6 +53,12 @@ newspacemap<-function(n,startspace,currspace,softlimit,hardlimit,blacklist,
            if(length(toomanyneib)>0){newadj[,toomanyneib]<-(1*(!blacklist&maxdag))[,toomanyneib]}
            toomanyneib<-which(apply(newadj,2,sum)>hardlimit)
            if(length(toomanyneib)>0){newadj[,toomanyneib]<-currspace[,toomanyneib]}
+           if(accum) {
+             newnewadj<-1*(newadj|currspace)
+             toomanyneib<-which(apply(newnewadj,2,sum)>hardlimit)
+             if(length(toomanyneib)>0){newnewadj[,toomanyneib]<-newadj[,toomanyneib]}
+             newadj<-newnewadj
+           }
          },
          "cpdag" = { 
            maxcp<-dagadj2cpadj(MCMCtrace[[maxN]])
@@ -65,11 +71,17 @@ newspacemap<-function(n,startspace,currspace,softlimit,hardlimit,blacklist,
            if(length(tootoomanyneib)>0) {newadj[,tootoomanyneib]<-MCMCtrace[[maxN]][,tootoomanyneib]}
            tootoomanyneib<-which(apply(newadj,2,sum)>hardlimit)
            if(length(tootoomanyneib)>0) {newadj[,tootoomanyneib]<-currspace[,tootoomanyneib]}
+           if(accum) {
+             newnewadj<-1*(newadj|currspace)
+             toomanyneib<-which(apply(newnewadj,2,sum)>hardlimit)
+             if(length(toomanyneib)>0){newnewadj[,toomanyneib]<-newadj[,toomanyneib]}
+             newadj<-newnewadj
+           }
          },
          "skeleton" = { 
            maxskel<-1*(MCMCtrace[[maxN]]|t(MCMCtrace[[maxN]]))
            newadj<-1*(!blacklist&(startspace|maxskel))
-           toomanyneib<-which(apply(newadj,2,sum)>4)
+           toomanyneib<-which(apply(newadj,2,sum)>7)
            if(length(toomanyneib)>0) {
              newadj[,toomanyneib]<-(1*(!blacklist&(startspace|dagadj2cpadj(MCMCtrace[[maxN]]))))[,toomanyneib]
            }
@@ -81,20 +93,34 @@ newspacemap<-function(n,startspace,currspace,softlimit,hardlimit,blacklist,
            if(length(tootoomanyneib)>0) {newadj[,tootoomanyneib]<-MCMCtrace[[maxN]][,tootoomanyneib]}
            tootoomanyneib<-which(apply(newadj,2,sum)>hardlimit)
            if(length(tootoomanyneib)>0) {newadj[,tootoomanyneib]<-currspace[,tootoomanyneib]}
+           if(accum) {
+             newnewadj<-1*(newadj|currspace)
+             toomanyneib<-which(apply(newnewadj,2,sum)>hardlimit)
+             if(length(toomanyneib)>0){newnewadj[,toomanyneib]<-newadj[,toomanyneib]}
+             newadj<-newnewadj
+           }
          }
   )
   return(newadj)
 }
 
-definestartspace<-function(alpha,param,cpdag=FALSE,n,algo="pc") {
-  if(is.null(alpha)) { if(n<50) {alpha<-0.4} else {alpha<-max(20/n,0.01)}}
+definestartspace<-function(alpha,param,cpdag=FALSE,algo="pc") {
+  if(is.null(alpha)) {alpha<-0.1}
   
   local_type <- param$type
-  if(local_type=="dbn"){ # 
-    othersliceskel <- definestartspace(alpha,param$otherslices,cpdag=cpdag,n,algo="pc")
-    firstsliceskel <- definestartspace(alpha,param$firstslice,cpdag=cpdag,n-param$nsmall,algo="pc")
+  if(local_type=="usr") {
+    if(param$pctesttype%in%c("bde","bge","bdecat")) {
+      local_type<-param$pctesttype
+    } 
+  }
+  
+  if(param$DBN){
+    
+    othersliceskel <- definestartspace(alpha,param$otherslices,cpdag=FALSE,algo="pc")
+    firstsliceskel <- definestartspace(alpha,param$firstslice,cpdag=FALSE,algo="pc")
     startspace <- othersliceskel
-    startspace[param$bgnodes,param$bgnodes] <- 1*(startspace[param$bgnodes,param$bgnodes] | firstsliceskel)
+    startspace[param$intstr$rows,param$intstr$cols] <- 1*(startspace[param$intstr$rows,param$intstr$cols] | firstsliceskel[param$intstr$rows,param$intstr$cols])
+
   } else { # otherwise use old versions
     
     if(local_type=="bde") {
@@ -134,10 +160,22 @@ definestartspace<-function(alpha,param,cpdag=FALSE,n,algo="pc") {
                                  indepTest = gaussCItest,
                                  alpha=alpha,labels=colnames(param$data),method="stable",verbose = FALSE)
       }
+    } else if (local_type=="usr") {
+
+        if(cpdag){
+        pc.skel<-pc(suffStat = param,
+                    indepTest = usrCItest, alpha = alpha, labels = colnames(param$data),
+                    verbose = FALSE)
+        
+      } else {
+        pc.skel<-pcalg::skeleton(suffStat = param,
+                                 indepTest = usrCItest, alpha = alpha, labels = colnames(param$data),
+                                 verbose = FALSE)
+      }
     }
     
     g<-pc.skel@graph
-    startspace<-1*(dag2adjacencymatrix(g))
+    startspace<-1*(graph2m(g))
   }
   return(startspace)
 }
